@@ -1,20 +1,20 @@
 class User:
     """
-    Class that represents an user
+    Represents an user
     """
 
     def __init__(self,id,login,display_name,type,broadcaster_type,description,profile_image_url,offline_image_url,view_count):
         """
-        Parameters:
-        id (int) -- User's ID
-        login (str) -- User's login
-        display_name (str) -- User's name
-        type (str) -- User type
-        broadcaster_type (str) -- User's range
-        description (str) -- User's description
-        profile_image_url (str) -- URL of the user's profile image
-        offline_image_url (str) -- URL of the image that is displayed when the user is not on stream
-        view_count (int) -- Number of user viewers
+        Args:
+            id (int): User's ID
+            login (str): User's login
+            display_name (str): User's name
+            type (str): User type
+            broadcaster_type (str): User's range
+            description (str): User's description
+            profile_image_url (str): URL of the user's profile image
+            offline_image_url (str): URL of the image that is displayed when the user is not on stream
+            view_count (int): Number of user viewers
         """
 
         self.id=id
